#pragma once
#define GIT_COMMIT_HASH    "36b2e0cfe0c6094dbc47bd42a437431315bb3087"
#define GIT_BRANCH         "v0.56.0"
#define GIT_COMMIT_MESSAGE "version: bump to 0.56.0"
#define GIT_COMMIT_DATE    "Mon Jul 20 07:50:48 2026"
#define GIT_DIRTY          "clean"
#define GIT_TAG            "v0.56.0"
#define GIT_COMMITS        "7625"

#define AQUAMARINE_VERSION "0.13.0"
// clang-format off
#define AQUAMARINE_VERSION_MAJOR 0
#define AQUAMARINE_VERSION_MINOR 13
#define AQUAMARINE_VERSION_PATCH 0
// clang-format on
#define HYPRLANG_VERSION     "0.6.8"
#define HYPRUTILS_VERSION    "0.14.0"
#define HYPRCURSOR_VERSION   "0.1.13"
#define HYPRGRAPHICS_VERSION "0.5.1"
